@@ -11,6 +11,7 @@ from typing import Union
 
 from .checks import is_bare
 from .compat import get_args
+from .tools import camel_to_snake
 from .types import CannotDispatch
 from .types import Forge
 from .types import NoneType
@@ -58,7 +59,7 @@ def forge_annotated_init(type_: Type[T], data: Any, forge: Forge) -> T:
     kwargs = dict(_cached_defaults(type_.__init__))
     kwargs.update(forged)
 
-    return type_(**kwargs)  # type: ignore
+    return type_(**kwargs)
 
 
 def forge_union(union: Union, data: Any, forge: Forge) -> Optional[T]:
@@ -89,3 +90,11 @@ def forge_mapping(type_: Type[Mapping], mapping: Mapping, forge: Forge) -> Mappi
         return dict(mapping)
     key_arg, value_arg = type_.__args__  # type: ignore
     return {forge(key_arg, k): forge(value_arg, v) for k, v in mapping.items()}
+
+
+def forge_literal(_: Any, literal: str, __: Any) -> str:
+    return str(literal)
+
+
+def filter_cammel_case(_: Any, data: Mapping[str, Any], __: Any) -> Mapping[str, Any]:
+    return {camel_to_snake(k): v for k, v in data.items()}
