@@ -1,17 +1,20 @@
 import sys
 from functools import lru_cache
 from typing import Any
+from typing import _eval_type  # type: ignore
 from typing import Dict
+from typing import Hashable
 from typing import Type
 from typing import TypeVar
 
-from .checks import has_annotated_init
+from .checks import has_annotated_init, is_literal
 from .checks import is_list
 from .checks import is_mapping
 from .checks import is_union
 from .compat import ForwardRef
-from .dispatchers.multi import MultiDispatcher
-from .forges import _clean_annotations
+from .dispatchers.functional import FunctionalDispatch
+from .dispatchers.multi import MultiDispatcher, sentry
+from .forges import _clean_annotations, forge_literal, filter_cammel_case
 from .forges import forge_annotated_init
 from .forges import forge_list
 from .forges import forge_mapping
@@ -19,16 +22,16 @@ from .forges import forge_none
 from .forges import forge_union
 from .types import CannotDispatch
 from .types import Check
-from .types import Forge
+from .types import Handler
 from .types import NoneType
 
-T = TypeVar("T")
+T = TypeVar("T", bound=Hashable)
 
 
 class Svarog:
     _refs_owners: Dict[ForwardRef, Type]
 
-    def __init__(self):
+    def __init__(self, snake_case: bool = False):
         self._refs_owners = {}
         self._dispatcher = MultiDispatcher()
 
@@ -38,11 +41,23 @@ class Svarog:
         self._dispatcher.register_func(is_list, forge_list)
         self._dispatcher.register_func(is_mapping, forge_mapping)
         self._dispatcher.register_func(is_union, forge_union)
+        self._dispatcher.register_func(is_literal, forge_literal)
 
-    def register_forge(self, type_: Type, forge: Forge) -> None:
+        self._filter = FunctionalDispatch(sentry)
+
+        if snake_case:
+            self.enable_snake_case()
+
+    def enable_snake_case(self):
+        self.register_filter(has_annotated_init, filter_cammel_case)
+
+    def register_filter(self, predicate: Check, forge: Handler) -> None:
+        self._filter.register(predicate)(forge)
+
+    def register_forge(self, type_: Type, forge: Handler) -> None:
         self._dispatcher.register_cls(type_, forge)
 
-    def register_mold(self, check: Check, forge: Forge) -> None:
+    def register_mold(self, check: Check, forge: Handler) -> None:
         self._dispatcher.register_func(check, forge)
 
     @lru_cache(None)
@@ -70,6 +85,10 @@ class Svarog:
 
         if type_ is Any:
             return data
+        try:
+            data = self._filter(type_, data, self.forge)
+        except CannotDispatch:
+            pass
 
         handler = self._dispatcher.dispatch(type_)
         try:
@@ -82,6 +101,6 @@ class Svarog:
             owner: Type = self._refs_owners[type_]
         except KeyError:
             raise RuntimeError(f"Unknown forward ref: {type_}")
-        return type_._evaluate(  # type: ignore
-            vars(sys.modules[owner.__module__]), getattr(owner, "__dict__", {})
+        return _eval_type(
+            type_, vars(sys.modules[owner.__module__]), getattr(owner, "__dict__", {})
         )
